@@ -76,7 +76,7 @@ class FaceLandmarkDetector(object):
         return landmarks
 
 class FaceCropper:
-    def __init__(self, landmark_predictor_path, resolution, mirror_padding, check_resolution, upper_limit_of_black_region_ratio):
+    def __init__(self, landmark_predictor_path, resolution, mirror_padding=False, check_resolution, upper_limit_of_black_region_ratio):
         self.resolution = resolution
         self.check_resolution = check_resolution
         self.mirror_padding = mirror_padding
